/*************************************************  Common Functions Header  **************************************************

	Red Rapids
	797 North Grove Rd
	Suite 101
	Richardson, TX 75081
	www.redrapids.com | support@redrapids.com

	Rev History: 12-19-2012:	Added ChannelCount and LoadGPIOSettings functions.
	Rev History: 10-16-2012:	Added transmitter (TX) functionality and interrupt timer.
	Rev History: 5-1-2012:		Inital release.

	Copyright 2012, Red Rapids, Inc.

*************************************************  Common Functions Header  **************************************************/

#ifndef _COMMON_FUNCTIONS_H_
#define _COMMON_FUNCTIONS_H_

#if defined(__cplusplus)
	extern "C" {
#endif

// Structure to store the LED on/off control settings.
typedef struct
{
	unsigned long LEDA;
	unsigned long LEDB;
} s_LEDControl;

// Structure to store GPIO and USER signal translator directions.
typedef struct
{
	unsigned long GPIODirection[6];
	unsigned long USERDirection[12];
} s_TranslatorDirection;

// Structure to store the results returned by a error status query to the device.
// Structure to store interrupt mask settings assigned to each type of error.
typedef struct
{
	unsigned long Bar[4];
	unsigned long Clock[8];
} s_ErrorStatus;

// Structure to store the results returned by an interrupt status query to the device.
typedef struct
{
	unsigned long Channel[4];
	unsigned long Error;
} s_GlobalStatus;

// Structure to store temperature results measured on the device.
typedef struct
{
	double FPGA;
	double QDR;
	double Connector;
	double ADC;
	double Center;
} s_Temperature;

// Prototypes for each of the common functions in alphabetic order.
unsigned long BusClose(s_Adapter *p_HW);
unsigned long BusOpen(s_Adapter *p_HW);
unsigned long ChannelCount(s_Adapter *p_HW, size_t RxTxSelect);
unsigned long ClockInit(s_Adapter *p_HW);
unsigned long ClockStatus(s_Adapter *p_HW, unsigned long ChipSelect);
unsigned long ErrorMask(s_Adapter *p_HW, s_ErrorStatus ErrorIntMask);
unsigned long FirmwareRevision(s_Adapter *p_HW);
unsigned long GetErrorStatus(s_Adapter *p_HW, s_ErrorStatus *p_ErrorStatus);
unsigned long GetGlobalStatus(s_Adapter *p_HW, s_GlobalStatus *p_GlobalStatus);
unsigned long GetTemperature(s_Adapter *p_HW, s_Temperature *p_Temperature);
unsigned long InterruptMask(s_Adapter *p_HW, unsigned long GlobalIntMask);
unsigned long InterruptResponse(s_Adapter *p_HW);
unsigned long InterruptTimeout(s_Adapter *p_HW, unsigned long IntTimeout);
unsigned long LoadTranslatorSettings(s_Adapter *p_HW, s_TranslatorDirection Translator);
unsigned long MicrosecondTimer(unsigned long Time);
unsigned long ModelNumber(s_Adapter *p_HW);
unsigned long Read(s_Adapter *p_HW, unsigned long Bar, unsigned long Off, unsigned long long *p_Value);
unsigned long Serial(s_Adapter *p_HW, unsigned long BusSelect, unsigned long MultiFunction, unsigned long Instruction, size_t AddressSize, unsigned long Data, size_t DataSize, unsigned long *p_ReadValue);
unsigned long SoftwareReset(s_Adapter *p_HW);
unsigned long SoftwareTrigger(s_Adapter *p_HW);
unsigned long Write(s_Adapter *p_HW, unsigned long Bar, unsigned long Off, unsigned long long Value);
unsigned long ProcessChannels(s_Adapter *p_HW);

#ifdef __cplusplus
}
#endif

#endif
